# AmrNet: Deep Learning Library

AmrNet is a lightweight deep learning library designed for simplicity and ease of use. It provides a set of basic tools to help you quickly build and train neural networks.

<!-- ## Features

- **Simple API:** Easily define, train, and evaluate neural networks with just a few lines of code.
- **Modularity:** Construct networks using pre-built layers or create custom layers for more flexibility.
- **Optimizers:** Choose from a variety of gradient descent optimizers to train your models.
- **Example Usage:** Check out the `examples` directory for code snippets and sample projects.

## Installation

```bash
pip install amrnet -->
